@@ -2,6 +2,11 @@
 from PyObjCTools.TestSupport import *
 from SearchKit import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestSKAnalysis (TestCase):
     def testConstants(self):
         self.assertIsInstance(kSKLanguageTypes, unicode)
