@@ -4,10 +4,20 @@ from SearchKit import *
 from Foundation import NSMutableData
 import os
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+try:
+    long
+except NameError:
+    long = int
+
 class TestSKIndex (TestCase):
     def testTypes(self):
-        self.assertIsInstance(SKIndexRef, objc.objc_class)
-        self.assertIsInstance(SKIndexDocumentIteratorRef, objc.objc_class)
+        self.assertIsCFType(SKIndexRef)
+        self.assertIsCFType(SKIndexDocumentIteratorRef)
 
     def testConstants(self):
         self.assertEqual(kSKIndexUnknown, 0)
@@ -28,7 +38,7 @@ class TestSKIndex (TestCase):
         self.assertResultIsCFRetained(SKIndexCreateWithURL)
         try:
             url = CFURLCreateWithFileSystemPath(
-                        None, u"/tmp/pyobjc.test.index",
+                        None, b"/tmp/pyobjc.test.index".decode('latin1'),
                         kCFURLPOSIXPathStyle, False)
             self.assertIsInstance(url, CFURLRef)
             ref = SKIndexCreateWithURL(
@@ -104,17 +114,19 @@ class TestSKIndex (TestCase):
         self.assertArgIsBOOL(SKIndexAddDocumentWithText, 3)
 
 
+        fn = b"/Library/Documentation/Acknowledgements.rtf".decode('latin1')
+        if not os.path.exists(fn):
+            fn = b"/Library/Documentation/AirPort Acknowledgements.rtf".decode('latin1')
+
         doc = SKDocumentCreateWithURL(
                 CFURLCreateWithFileSystemPath(
-                    None, u"/Library/Documentation/Acknowledgements.rtf",
+                    None, fn,
                     kCFURLPOSIXPathStyle, False))
 
-
         v = SKIndexAddDocumentWithText(ref, 
                 doc, "hello world", True)
         self.failUnless(v)
 
-
         self.assertResultIsBOOL(SKIndexAddDocument)
         self.assertArgIsBOOL(SKIndexAddDocument, 3)
         v = SKIndexAddDocument(ref, doc, None, True)
@@ -135,11 +147,8 @@ class TestSKIndex (TestCase):
         v = SKIndexCopyDocumentForDocumentID(ref, v)
         self.failUnless(v is doc)
 
-        v = SKIndexRenameDocument(ref, doc, "osx-acks.rtf")
-        self.failUnless(v is True)
-
-        v = SKIndexMoveDocument(ref, doc, None)
-        self.failUnless(v is True)
+        r = SKIndexFlush(ref)
+        self.assertIs(r, True)
 
         self.assertResultIsCFRetained(SKIndexDocumentIteratorCreate)
         it = SKIndexDocumentIteratorCreate(ref, None)
@@ -158,9 +167,12 @@ class TestSKIndex (TestCase):
         v = SKIndexGetDocumentTermCount(ref, docID)
         self.assertIsInstance(v, (int, long))
 
+
         v = SKIndexCopyTermIDArrayForDocumentID(ref, docID)
         self.assertIsInstance(v, CFArrayRef)
-        tID = v[0]
+
+        tID =  SKIndexGetMaximumTermID(ref) - 1
+
 
         v = SKIndexGetDocumentTermFrequency(ref, docID, tID)
         self.assertIsInstance(v, (int, long))
@@ -172,16 +184,22 @@ class TestSKIndex (TestCase):
         self.assertIsInstance(v, (int, long))
 
         v = SKIndexCopyDocumentIDArrayForTermID(ref, tID)
-        self.assertIsInstance(v, CFArrayRef)
+        self.assertIsInstance(v, (CFArrayRef, type(None)))
 
         v = SKIndexCopyTermStringForTermID(ref, tID)
-        self.assertIsInstance(v, unicode)
+        self.assertIsInstance(v, (unicode, type(None)))
 
         v = SKIndexGetTermIDForTermString(ref, v)
         self.assertIsInstance(v, (int, long))
 
         SKLoadDefaultExtractorPlugIns()
 
+        v = SKIndexRenameDocument(ref, doc, "osx-acks.rtf")
+        self.failUnless(v is True)
+
+        v = SKIndexMoveDocument(ref, doc, None)
+        self.failUnless(v is True)
+
         v = SKIndexRemoveDocument(ref, doc)
         self.failUnless(v)
 
